@@ -24,7 +24,7 @@ The following functions are also imported:
 from __future__ import unicode_literals
 
 __author__ = "Caleb P. Burns"
-__copyright__ = "Copyright © 2013-2017 Caleb P. Burns"
+__copyright__ = "Copyright © 2013-2018 Caleb P. Burns"
 __created__ = "2013-10-12"
 __credits__ = [
 	"dahlia <https://github.com/dahlia>",
@@ -39,14 +39,18 @@ __credits__ = [
 	"adrienverge <https://github.com/adrienverge>",
 	"AndersBlomdell <https://github.com/AndersBlomdell>",
 	"highb <https://github.com/highb>",
-	"thmxv <https://github.com/thmxv>"
+	"thmxv <https://github.com/thmxv>",
+	"wimglenn <https://github.com/wimglenn>",
+	"hugovk <https://github.com/hugovk>",
+        "dcecile <https://github.com/dcecile>",
+        "mroutis <https://github.com/mroutis>",
 ]
 __email__ = "cpburnz@gmail.com"
 __license__ = "MPL 2.0"
 __project__ = "pathspec"
 __status__ = "Development"
-__updated__ = "2018-08-14"
-__version__ = "0.5.7"
+__updated__ = "2019-10-03"
+__version__ = "0.6.0"
 
 from .pathspec import PathSpec
 from .pattern import Pattern, RegexPattern
